%define         majornum        4
%define         libname         %mklibname %{name} %{majornum}
%define         develname       %mklibname %{name} -d
%define         srcname         Cuba
%global        _legacy_common_support 1

Name:           cuba
Version:        4.2.2
Release:        %mkrel 1
Summary:        A library for multidimensional numerical integration
License:        LGPLv3
Group:          Sciences/Computer science

URL:            http://www.feynarts.de/cuba
Source0:        http://www.feynarts.de/cuba/%{srcname}-%{version}.tar.gz
#build shared lib
Patch0:         cuba-4.2.1-shlib.patch
#remove all deps to Wolfwram Mathematica
Patch1:         cuba-4.2-nukewolf.patch
#sanity settings:
#https://github.com/MoMEMta/MoMEMta/blob/master/external/cuba/
#set IPC pages to be removed after process detachment
#increase definition of zero from 1pow(104) -> pow(250)
Patch2:         cuba-4.2-stddecl-safe.patch
Patch3:         cuba-4.2-Qt5.patch

BuildRequires:  gcc-c++
BuildRequires:  gcc-gfortran
%ifarch %{ix86} x86_64
BuildRequires:  quadmath-devel
%endif
BuildRequires:  libgomp-devel
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Widgets)

%description
The Cuba library offers a choice of four independent routines for
multidimensional numerical integration: Vegas, Suave, Divonne, and
Cuhre. All four have a C/C++ and Fortran interface and can integrate
vector integrands. Their invocation is very similar, so it is easy to
substitute one method by another for cross-checking. For further
safeguarding, the output is supplemented by a chi-square probability
which quantifies the reliability of the error estimate. C functions
can be called from Fortran directly, so there is no need for adapter
code. Similarly, linking Fortran code with the library is
straightforward and requires no extra tools. In Fortran and C/C++ the
Cuba library can (and usually does) automatically parallelize the
sampling of the integrand.


%package -n %{libname}
License:        LGPLv3
Summary:        The Cuba library for multidimensional numerical integration
Group:          System/Libraries
Provides:       %{name} = %{version}-%{release}

%description -n %{libname}
The Cuba library offers a choice of four independent routines for
multidimensional numerical integration: Vegas, Suave, Divonne, and
Cuhre. All four have a C/C++ and Fortran interface and can integrate
vector integrands. Their invocation is very similar, so it is easy to
substitute one method by another for cross-checking. For further
safeguarding, the output is supplemented by a chi-square probability
which quantifies the reliability of the error estimate. C functions
can be called from Fortran directly, so there is no need for adapter
code. Similarly, linking Fortran code with the library is
straightforward and requires no extra tools. In Fortran and C/C++ the
Cuba library can (and usually does) automatically parallelize the
sampling of the integrand.


%package -n %{develname}
License:        LGPLv3
Summary:        Headers and modules for the Cuba library
Group:          Development/Other
Provides:       %{name}-devel = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}
Obsoletes:      %{_lib}cuba-static-devel < 4.2-4

%description -n %{develname}
%{summary}.


%prep

%setup -q -n %{srcname}-%{version}
%autopatch -p1
#patch0 -p1 -b .orig
#patch1 -p1 -b .orig
#patch2 -p1 -b .orig
#patch3 -p1 -b .orig


%build
%define _legacy_common_support 1
autoreconf -fi
%configure
#parallel build broken
%__make


%install
%make_install
%__rm -f %{buildroot}%{_datadir}/cuba.pdf

#nuke la files from libtools
find %{buildroot} -name '*.*a' -delete


%files
%doc COPYING cuba.pdf
%{_bindir}/partview


%files -n %{libname}
%{_libdir}/libcuba.so.%{majornum}{,.*}


%files -n %{develname}
%doc ChangeLog
%{_includedir}/*.h
%{_libdir}/libcuba.so



%changelog
* Fri Aug 26 2022 eatdirt <eatdirt> 4.2.2-1.mga9
+ Revision: 1880547
- Update to version 4.2.2

* Sun Apr 03 2022 umeabot <umeabot> 4.2.1-3.mga9
+ Revision: 1842026
- Mageia 9 Mass Rebuild

* Wed Dec 16 2020 umeabot <umeabot> 4.2.1-2.mga8
+ Revision: 1658278
- Rebuild for new Qt5

* Wed Dec 02 2020 eatdirt <eatdirt> 4.2.1-1.mga8
+ Revision: 1651699
- Upgrade to version 4.2.1

* Sun Aug 23 2020 joequant <joequant> 4.2-8.mga8
+ Revision: 1618148
- fix gcc10 build
- fix gcc10 compile

* Sat Feb 15 2020 umeabot <umeabot> 4.2-7.mga8
+ Revision: 1524431
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Mar 30 2019 umeabot <umeabot> 4.2-6.mga7
+ Revision: 1381487
- Qt5 Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 4.2-5.mga7
+ Revision: 1297345
- Mageia 7 Mass Rebuild

* Thu May 17 2018 daviddavid <daviddavid> 4.2-4.mga7
+ Revision: 1230021
- rebuild with fixed release tag

* Thu May 17 2018 daviddavid <daviddavid> 4.2-3.mga7
+ Revision: 1230020
- port to Qt5
- remove unneeded static libraries

* Mon May 08 2017 eatdirt <eatdirt> 4.2-3.mga6
+ Revision: 1099687
- Add patch to sanitize ipc memory and zero definition

* Wed May 03 2017 eatdirt <eatdirt> 4.2-2.mga6
+ Revision: 1098849
- Fix missing symbols in the shared library (divonne_)

* Sat Apr 22 2017 eatdirt <eatdirt> 4.2-1.mga6
+ Revision: 1097070
- imported package cuba

